==> mriconvert_2.0.4.orig.tar.gz: DicomTags.h <==
/// DicomTags.h
/**
*/

#define DT_ACQUISITIONNUMBER DicomTag(0x0020, 0x0012)
#define DT_ACQUISITIONTIME DicomTag(0x0008, 0x0032)
#define DT_BITSALLOCATED DicomTag(0x0028, 0x0100)
#define DT_CLINICALTRIALPROTOCOLNAME DicomTag(0x0012, 0x0021)
#define DT_DIMENSIONINDEXSEQUENCE DicomTag(0x0020, 0x9222)
#define DT_ECHONUMBER DicomTag(0x0018, 0x0086)
#define DT_FLIPANGLE DicomTag(0x0018, 0x1314)
#define DT_FRAMEACQUISITIONNUMBER DicomTag(0x0020, 0x9156)
#define DT_FRAMEINCREMENTPOINTER DicomTag(0x0028, 0x0009)
#define DT_IMAGECOLUMNS DicomTag(0x0028, 0x0011)
#define DT_IMAGECOMMENTS DicomTag(0x0020, 0x4000)
#define DT_IMAGEORIENTATIONPATIENT DicomTag(0x0020, 0x0037)
#define DT_IMAGEPOSITIONPATIENT DicomTag(0x0020, 0x0032)
#define DT_IMAGEROWS DicomTag(0x0028, 0x0010)
#define DT_IMAGETYPE DicomTag(0x0008, 0x0008)
#define DT_INSTANCENUMBER DicomTag(0x0020, 0x0013)
#define DT_INVERSIONTIME DicomTag(0x0018, 0x0082)
#define DT_LARGESTIMAGEPIXELVALUE DicomTag(0x0028, 0x0107)
#define DT_MANUFACTURER DicomTag(0x0008, 0x0070)
#define DT_MFGROUPLENGTH DicomTag(0x0002, 0x0000)
#define DT_MFSOPCLASS DicomTag(0x0002, 0x0002)
#define DT_MFSOPINSTANCE DicomTag(0x0002, 0x0003)
#define DT_MFTRANSFERSYNTAX DicomTag(0x0002, 0x0010)
#define DT_MODALITY DicomTag(0x0008, 0x0060)
#define DT_MODELNAME DicomTag(0x0008, 0x1090)
#define DT_MRACQUISITIONTYPE DicomTag(0x0018, 0x0023)
#define DT_NUMBEROFAVERAGES DicomTag(0x0018, 0x0083)
#define DT_NUMBEROFFRAMES DicomTag(0x0028, 0x0008)
#define DT_NUMBEROFTEMPORALPOSITIONS DicomTag(0x0020, 0x0105)
#define DT_OVERLAYBITSALLOCATED DicomTag(0x6000, 0x0100)
#define DT_PATIENTID DicomTag(0x0010, 0x0020)
#define DT_PATIENTNAME DicomTag(0x0010, 0x0010)
#define DT_PERFRAMEFUNCTIONALGROUPSSEQUENCE DicomTag(0x5200, 0x9230)
#define DT_PHASEENCODINGDIRECTION DicomTag(0x0018, 0x1312)
#define DT_PHOTOMETRICINTERPRETATION DicomTag(0x0028, 0x0004)
#define DT_PIXELDATA DicomTag(0x7fe0, 0x0010)
#define DT_PIXELREPRESENTATION DicomTag(0x0028, 0x0103)
#define DT_PIXELSPACING DicomTag(0x0028, 0x0030)
#define DT_PROTOCOLNAME DicomTag(0x0018, 0x1030)
#define DT_PULSESEQUENCENAME DicomTag(0x0018, 0x9005)
#define DT_RECEIVECOILMANUFACTURERNAME DicomTag(0x0018, 0x9041)
#define DT_REPETITIONTIME DicomTag(0x0018, 0x0080)
#define DT_RESCALEINTERCEPT DicomTag(0x0028, 0x1052)
#define DT_RESCALESLOPE DicomTag(0x0028, 0x1053)
#define DT_SAMPLESPERPIXEL DicomTag(0x0028, 0x0002)
#define DT_SECONDARYCAPTUREDEVICESOFTWAREVERSION DicomTag(0x0018, 0x1019)
#define DT_SEQUENCENAME DicomTag(0x0018, 0x0024)
#define DT_SERIESDATE DicomTag(0x0008, 0x0021)
#define DT_SERIESDESCRIPTION DicomTag(0x0008, 0x103E)
#define DT_SERIESINSTANCEUID DicomTag(0x0020, 0x000E)
#define DT_SERIESNUMBER DicomTag(0x0020, 0x0011)
#define DT_SERIESTIME DicomTag(0x0008, 0x0031)
#define DT_SHAREDFUNCTIONALGROUPSSEQUENCE DicomTag(0x5200, 0x9229)
#define DT_SLICESPACING DicomTag(0x0018, 0x0088)
#define DT_SLICETHICKNESS DicomTag(0x0018, 0x0050)
#define DT_SOFTWAREVERSION DicomTag(0x0018, 0x1020)
#define DT_SOPCLASS DicomTag(0x0008, 0x0016)
#define DT_SOPINSTANCE DicomTag(0x0008, 0x0018)
#define DT_STUDYDATE DicomTag(0x0008, 0x0020)
#define DT_STUDYDESCRIPTION DicomTag(0x0008, 0x1030)
#define DT_STUDYID DicomTag(0x0020, 0x0010)
#define DT_STUDYINSTANCEUID DicomTag(0x0020, 0x000D)
#define DT_STUDYTIME DicomTag(0x0008, 0x0030)
#define DT_TEMPORALPOSITIONID DicomTag(0x0020, 0x0100)
#define DT_TRANSMITCOILMANUFACTURERNAME DicomTag(0x0018, 0x9050)
#define DT_VARIABLEFLIPANGLEFLAG DicomTag(0x0018, 0x1315)
#define DT_WINDOWCENTERANDWIDTHEXPLANATION DicomTag(0x0028, 0x1055)
#define DT_WINDOWCENTER DicomTag(0x0028, 0x1050)
#define DT_WINDOWWIDTH DicomTag(0x0028, 0x1051)

==> mriconvert_2.0.7.orig.tar.gz: DicomTags.h <==
/// DicomTags.h
/** Macros for various DICOM tags.
*/

#define DT_ACQUISITIONNUMBER DicomTag(0x0020, 0x0012)
#define DT_ACQUISITIONTIME DicomTag(0x0008, 0x0032)
#define DT_BITSALLOCATED DicomTag(0x0028, 0x0100)
#define DT_CHARACTERSET DicomTag(0x0008, 0x0005)
#define DT_CLINICALTRIALPROTOCOLNAME DicomTag(0x0012, 0x0021)
#define DT_DIMENSIONINDEXSEQUENCE DicomTag(0x0020, 0x9222)
#define DT_ECHONUMBER DicomTag(0x0018, 0x0086)
#define DT_FLIPANGLE DicomTag(0x0018, 0x1314)
#define DT_FRAMEACQUISITIONNUMBER DicomTag(0x0020, 0x9156)
#define DT_FRAMEINCREMENTPOINTER DicomTag(0x0028, 0x0009)
#define DT_IMAGECOLUMNS DicomTag(0x0028, 0x0011)
#define DT_IMAGECOMMENTS DicomTag(0x0020, 0x4000)
#define DT_IMAGEORIENTATIONPATIENT DicomTag(0x0020, 0x0037)
#define DT_IMAGEPOSITIONPATIENT DicomTag(0x0020, 0x0032)
#define DT_IMAGEROWS DicomTag(0x0028, 0x0010)
#define DT_IMAGETYPE DicomTag(0x0008, 0x0008)
#define DT_INSTANCENUMBER DicomTag(0x0020, 0x0013)
#define DT_INVERSIONTIME DicomTag(0x0018, 0x0082)
#define DT_LARGESTIMAGEPIXELVALUE DicomTag(0x0028, 0x0107)
#define DT_MANUFACTURER DicomTag(0x0008, 0x0070)
#define DT_MFGROUPLENGTH DicomTag(0x0002, 0x0000)
#define DT_MFSOPCLASS DicomTag(0x0002, 0x0002)
#define DT_MFSOPINSTANCE DicomTag(0x0002, 0x0003)
#define DT_MFTRANSFERSYNTAX DicomTag(0x0002, 0x0010)
#define DT_MODALITY DicomTag(0x0008, 0x0060)
#define DT_MODELNAME DicomTag(0x0008, 0x1090)
#define DT_MRACQUISITIONTYPE DicomTag(0x0018, 0x0023)
#define DT_NUMBEROFAVERAGES DicomTag(0x0018, 0x0083)
#define DT_NUMBEROFFRAMES DicomTag(0x0028, 0x0008)
#define DT_NUMBEROFTEMPORALPOSITIONS DicomTag(0x0020, 0x0105)
#define DT_OVERLAYBITSALLOCATED DicomTag(0x6000, 0x0100)
#define DT_PATIENTID DicomTag(0x0010, 0x0020)
#define DT_PATIENTNAME DicomTag(0x0010, 0x0010)
#define DT_PATIENTBIRTHDATE DicomTag(0x0010, 0x0030)
#define DT_PERFRAMEFUNCTIONALGROUPSSEQUENCE DicomTag(0x5200, 0x9230)
#define DT_PHASEENCODINGDIRECTION DicomTag(0x0018, 0x1312)
#define DT_PHOTOMETRICINTERPRETATION DicomTag(0x0028, 0x0004)
#define DT_PIXELDATA DicomTag(0x7fe0, 0x0010)
#define DT_PIXELREPRESENTATION DicomTag(0x0028, 0x0103)
#define DT_PIXELSPACING DicomTag(0x0028, 0x0030)
#define DT_PROTOCOLNAME DicomTag(0x0018, 0x1030)
#define DT_PULSESEQUENCENAME DicomTag(0x0018, 0x9005)
#define DT_RECEIVECOILMANUFACTURERNAME DicomTag(0x0018, 0x9041)
#define DT_REPETITIONTIME DicomTag(0x0018, 0x0080)
#define DT_RESCALEINTERCEPT DicomTag(0x0028, 0x1052)
#define DT_RESCALESLOPE DicomTag(0x0028, 0x1053)
#define DT_SAMPLESPERPIXEL DicomTag(0x0028, 0x0002)
#define DT_SECONDARYCAPTUREDEVICESOFTWAREVERSION DicomTag(0x0018, 0x1019)
#define DT_SEQUENCENAME DicomTag(0x0018, 0x0024)
#define DT_SERIESDATE DicomTag(0x0008, 0x0021)
#define DT_SERIESDESCRIPTION DicomTag(0x0008, 0x103E)
#define DT_SERIESINSTANCEUID DicomTag(0x0020, 0x000E)
#define DT_SERIESNUMBER DicomTag(0x0020, 0x0011)
#define DT_SERIESTIME DicomTag(0x0008, 0x0031)
#define DT_SHAREDFUNCTIONALGROUPSSEQUENCE DicomTag(0x5200, 0x9229)
#define DT_SLICESPACING DicomTag(0x0018, 0x0088)
#define DT_SLICETHICKNESS DicomTag(0x0018, 0x0050)
#define DT_SOFTWAREVERSION DicomTag(0x0018, 0x1020)
#define DT_SOPCLASS DicomTag(0x0008, 0x0016)
#define DT_SOPINSTANCE DicomTag(0x0008, 0x0018)
#define DT_STUDYDATE DicomTag(0x0008, 0x0020)
#define DT_STUDYDESCRIPTION DicomTag(0x0008, 0x1030)
#define DT_STUDYID DicomTag(0x0020, 0x0010)
#define DT_STUDYINSTANCEUID DicomTag(0x0020, 0x000D)
#define DT_STUDYTIME DicomTag(0x0008, 0x0030)
#define DT_TEMPORALPOSITIONID DicomTag(0x0020, 0x0100)
#define DT_TRANSMITCOILMANUFACTURERNAME DicomTag(0x0018, 0x9050)
#define DT_VARIABLEFLIPANGLEFLAG DicomTag(0x0018, 0x1315)
#define DT_WINDOWCENTERANDWIDTHEXPLANATION DicomTag(0x0028, 0x1055)
#define DT_WINDOWCENTER DicomTag(0x0028, 0x1050)
#define DT_WINDOWWIDTH DicomTag(0x0028, 0x1051)
